==> HTML-WikiConverter-DokuWikiFCK-0.28.tgz: fckg/helper.php <==
<?php
/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Myron Turner <turnermm02@shaw.ca>
 */
 
// must be run within Dokuwiki
if (!defined('DOKU_INC')) die();
 
class helper_plugin_fckg extends DokuWiki_Plugin {
 
  function getInfo(){
    return array(
      'author' => 'Myron Turner',
      'date'   => '2007-05-15',
      'name'   => 'DokuWikiFCK/fckg',
      'desc'   => 'Various Helper Functions',
      'url'    => 'http://www.mturner.org',
    );
  }
 
  function getMethods(){
    $result = array();
    $result[] = array(
      'name'   => 'registerOnLoad',
      'desc'   => 'register some javascript to the window.onload js event',
      'params' => array('js' => 'string'),
      'return' => array('html' => 'string'),
    );
    return $result;
  }

  function registerOnLoad($js){
  global $ID;
  global $lang;
  $preview_button = $lang['btn_preview'];
  $media_tmp_ns = preg_match('/:/',$ID) ? preg_replace('/:\w+$/',"",$ID,1) : "";    
  $locktimer_msg = "Your lock for editing this page is about to expire in a minute.\\n"
                . "\\nIf you have the necessary permissions you can \\n"
                . "disable the lock timer by checking the lock timer unset box.\\n"  
                . "Otherwise you may click Save and then Edit or else the Refresh button.";

    // recovery is text recovered from drafts
    // recovery is set up in meta.php
    //|(class\s*=\s*code)
    $section_edit = false; 
    $recovery = isset($_REQUEST['recovery']) ? $_REQUEST['recovery'] : '__null';
    if($recovery != '__null' && !preg_match('/([=]{3,})|(<code>)|(class\s*=\s*code)/mi',$recovery))  {
           $recovery = preg_replace('/[\n\r]+/', ' ',$recovery); 
           $recovery  = addcslashes ($recovery, '"'); 
           $recovery = preg_replace('/[\xa0-\xff]/', "&nbsp;", $recovery );    
    }
    else { 
        $recovery = '__null';   
    }
 
    return <<<end_of_string

<script type='text/javascript'>

var FCKRecovery = "$recovery";
var oldonload = window.onload;
var ourLockTimerINI = false;

if (typeof window.onload != 'function') {
  window.onload = function(){
    $js

  }
} else {
  window.onload = function() 
  {
    oldonload();
    $js  

  }
}

  
  function getCurrentWikiNS() {
        var DWikiMediaManagerCommand_ns = '$media_tmp_ns';
        return DWikiMediaManagerCommand_ns;
  }
 
 var ourLockTimerRefreshID;
 var ourLockTimerIsSet = true;
 var ourLockTimerWarningtimerID;
 var ourFCKEditorNode = null;
 var ourLockTimerIntervalID;
   /**
        handles both mousepresses and keystrokes from FCKeditor window
        assigned in fckeditor.html
  */
 function handlemouspress(e) { 
   if(ourLockTimerIsSet) {
         lockTimerRefresh();
   }

 }

 function unsetDokuWikiLockTimer() {
     
    if(window.locktimer && !ourLockTimerINI) {
        locktimer.old_reset = locktimer.reset;
        locktimer.old_warning = locktimer.warning;        
        ourLockTimerINI=true;
    }
    else {
        window.setTimeout("unsetDokuWikiLockTimer()", 600);

    }
  
  locktimer.reset = function(){
        locktimer.clear();  /// alert(locktimer.timeout);
        window.clearTimeout(ourLockTimerWarningtimerID);
        ourLockTimerWarningtimerID =  window.setTimeout(function () { locktimer.warning(); }, locktimer.timeout);
     //  ourLockTimerWarningtimerID =  window.setTimeout(function () { locktimer.warning(); }, (2*60*1000));
      
   };

   locktimer.warning = function(){    
        window.clearTimeout(ourLockTimerWarningtimerID);

        if(ourLockTimerIsSet) {
            if(locktimer.msg.match(/$preview_button/i)) {
                locktimer.msg = locktimer.msg.replace(/$preview_button/i, "Refresh");      
             }
            alert(locktimer.msg);
        }
        else {
            alert("$locktimer_msg");
        }
     };
     

    locktimer.ourLockTimerReset = locktimer.reset;
    locktimer.our_lasttime = new Date();
    lockTimerRefresh();

   }

 function lockTimerRefresh() {
        var now = new Date();

        if(now.getTime() - locktimer.our_lasttime.getTime() > 30*1000){       
            window.clearTimeout(ourLockTimerWarningtimerID);
            var params = 'call=lock&id='+encodeURIComponent(locktimer.pageid);
            if(ourFCKEditorNode) {  
                var dwform = $('dw__editform');
                dwform.elements.wikitext.value = ourFCKEditorNode.innerHTML;
                params += '&prefix='+encodeURIComponent(dwform.elements.prefix.value);
                params += '&wikitext='+encodeURIComponent(dwform.elements.wikitext.value);
                params += '&suffix='+encodeURIComponent(dwform.elements.suffix.value);
                params += '&date='+encodeURIComponent(dwform.elements.date.value);
            }
            locktimer.sack.runAJAX(params);
            locktimer.our_lasttime = now;
          
        }

 }


  /** tied into but does not depend upon draft system:
  *   puts recovered text into FCKeditor window
  *     1. when draft recovery is accessed by DW
  *     2. when switching between FCKeditor window and FCK Preview and back
  *           contents of FCKeditor window are saved and then restored when clicking FCK Edit button
  *           in FCK Preview mode; this insures that any edits made in FCKeditor window will
  *           not be lost, because it will not have been saved to file and when switching back from
  *           preview mode DW re-reads the file.
  */  
 function getRecoveredText() {
      if(!ourFCKEditorNode) return;
      var fck_text = $('fckEd__text');
      if(FCKRecovery != '__null') {
         ourFCKEditorNode.innerHTML =  FCKRecovery ;       
         return;
      }
      if(fck_text) {
           ourFCKEditorNode.innerHTML = fck_text.innerHTML;
           return;
      }
  
 }

 function resetDokuWikiLockTimer(delete_checkbox) {

        var dom_checkbox = document.getElementById('fckg_timer');
        var dom_label = document.getElementById('fckg_timer_label');
        locktimer.clear();     
        if(ourLockTimerIsSet) {

             ourLockTimerIsSet = false;             
             locktimer.reset = locktimer.old_reset; 
             locktimer.refresh(); 
             dom_checkbox.style.display = 'inline';
             dom_label.style.display = 'inline';
             return;
        }
      
     if(delete_checkbox) {
       dom_checkbox.style.display = 'none';
       dom_label.style.display = 'none';
     }

       ourLockTimerIsSet = true;
       locktimer.reset = locktimer.ourLockTimerReset;     
       lockTimerRefresh();
          
 }

function renewLock() {
  if(ourLockTimerIsSet) {
         lockTimerRefresh();
   }
   else locktimer.refresh();
   locktimer.reset();
    
}

function disableDokuWikiLockTimer() {
  resetDokuWikiLockTimer(false);
  if(ourLockTimerIntervalID) {
     window.clearInterval(ourLockTimerIntervalID);
  }
  if(ourLockTimerIsSet) { 
    ourLockTimerIntervalID = window.setInterval(function () { locktimer.refresh(); }, 30000);   
  }
}
var oDokuWiki_FCKEditorInstance;
function FCKeditor_OnComplete( editorInstance )
{
  oDokuWiki_FCKEditorInstance = editorInstance;
}

</script>
end_of_string;
  }
}
?>

==> HTML-WikiConverter-DokuWikiFCK-0.31.tgz: fckg/helper.php <==
<?php
/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Myron Turner <turnermm02@shaw.ca>
 */
 
// must be run within Dokuwiki
if (!defined('DOKU_INC')) die();
 
class helper_plugin_fckg extends DokuWiki_Plugin {
 
  function getInfo(){
    return array(
      'author' => 'Myron Turner',
      'date'   => '2007-05-15',
      'name'   => 'DokuWikiFCK/fckg',
      'desc'   => 'Various Helper Functions',
      'url'    => 'http://www.mturner.org',
    );
  }
 
  function getMethods(){
    $result = array();
    $result[] = array(
      'name'   => 'registerOnLoad',
      'desc'   => 'register some javascript to the window.onload js event',
      'params' => array('js' => 'string'),
      'return' => array('html' => 'string'),
    );
    return $result;
  }

  function registerOnLoad($js){
  global $ID;
  global $lang;
  $preview_button = $lang['btn_preview'];
  $media_tmp_ns = preg_match('/:/',$ID) ? preg_replace('/:\w+$/',"",$ID,1) : "";    
  $locktimer_msg = "Your lock for editing this page is about to expire in a minute.\\n"
                . "\\nIf you have the necessary permissions you can \\n"
                . "disable the lock timer by checking the lock timer unset box.\\n"  
                . "Otherwise you may click Save and then Edit or else the Refresh button.";

    // recovery is text recovered from drafts
    // recovery is set up in meta.php
    //|(class\s*=\s*code)
    $section_edit = false; 
    $recovery = isset($_REQUEST['recovery']) ? $_REQUEST['recovery'] : '__null';
    if($recovery != '__null' && !preg_match('/([=]{3,})|(<code>)|(class\s*=\s*code)/mi',$recovery))  {
           $recovery = preg_replace('/[\n\r]+/', ' ',$recovery); 
           $recovery  = addcslashes ($recovery, '"'); 
           $recovery = preg_replace('/[\xa0-\xff]/', "&nbsp;", $recovery );    
    }
    else { 
        $recovery = '__null';   
    }

  global $INFO; 
  //$user_type = 'user';
  if(!isset($INFO['userinfo'])) {
    $user_type = 'visitor';
  }
  else {
   $user_type = 'user';
  }
 
    return <<<end_of_string



<script type='text/javascript'>

var FCKRecovery = "$recovery";
var oldonload = window.onload;
var ourLockTimerINI = false;

if (typeof window.onload != 'function') {
  window.onload = function(){
    $js

  }
} else {
  window.onload = function() 
  {
    oldonload();
    $js  

  }
}

  
  function getCurrentWikiNS() {
        var DWikiMediaManagerCommand_ns = '$media_tmp_ns';
        return DWikiMediaManagerCommand_ns;
  }
 
 var ourLockTimerRefreshID;
 var ourLockTimerIsSet = true;
 var ourLockTimerWarningtimerID;
 var ourFCKEditorNode = null;
 var ourLockTimerIntervalID;
   /**
        handles both mousepresses and keystrokes from FCKeditor window
        assigned in fckeditor.html
  */
 function handlemouspress(e) { 
   if(ourLockTimerIsSet) {
         lockTimerRefresh();
   }

 }

 function unsetDokuWikiLockTimer() {
     
    if(window.locktimer && !ourLockTimerINI) {
        locktimer.old_reset = locktimer.reset;
        locktimer.old_warning = locktimer.warning;        
        ourLockTimerINI=true;
    }
    else {
        window.setTimeout("unsetDokuWikiLockTimer()", 600);

    }
  
  locktimer.reset = function(){
        locktimer.clear();  /// alert(locktimer.timeout);
        window.clearTimeout(ourLockTimerWarningtimerID);
        ourLockTimerWarningtimerID =  window.setTimeout(function () { locktimer.warning(); }, locktimer.timeout);
     //  ourLockTimerWarningtimerID =  window.setTimeout(function () { locktimer.warning(); }, (2*60*1000));
      
   };

   locktimer.warning = function(){    
        window.clearTimeout(ourLockTimerWarningtimerID);

        if(ourLockTimerIsSet) {
            if(locktimer.msg.match(/$preview_button/i)) {
                locktimer.msg = locktimer.msg.replace(/$preview_button/i, "Refresh");      
             }
            alert(locktimer.msg);
        }
        else {
            alert("$locktimer_msg");
        }
     };
     

    locktimer.ourLockTimerReset = locktimer.reset;
    locktimer.our_lasttime = new Date();
    lockTimerRefresh();

   }

 function lockTimerRefresh() {
        var now = new Date();

        if(now.getTime() - locktimer.our_lasttime.getTime() > 30*1000){       
            window.clearTimeout(ourLockTimerWarningtimerID);
            var params = 'call=lock&id='+encodeURIComponent(locktimer.pageid);
            if(ourFCKEditorNode) {  
                var dwform = $('dw__editform');
                dwform.elements.wikitext.value = ourFCKEditorNode.innerHTML;
                params += '&prefix='+encodeURIComponent(dwform.elements.prefix.value);
                params += '&wikitext='+encodeURIComponent(dwform.elements.wikitext.value);
                params += '&suffix='+encodeURIComponent(dwform.elements.suffix.value);
                params += '&date='+encodeURIComponent(dwform.elements.date.value);
            }
            locktimer.sack.runAJAX(params);
            locktimer.our_lasttime = now;
          
        }

 }


  /** tied into but does not depend upon draft system:
  *   puts recovered text into FCKeditor window
  *     1. when draft recovery is accessed by DW
  *     2. when switching between FCKeditor window and FCK Preview and back
  *           contents of FCKeditor window are saved and then restored when clicking FCK Edit button
  *           in FCK Preview mode; this insures that any edits made in FCKeditor window will
  *           not be lost, because it will not have been saved to file and when switching back from
  *           preview mode DW re-reads the file.
  */  
 function getRecoveredText() {
      if(!ourFCKEditorNode) return;
      var fck_text = $('fckEd__text');
      if(FCKRecovery != '__null') {
         ourFCKEditorNode.innerHTML =  FCKRecovery ;       
         return;
      }
      if(fck_text) {
           ourFCKEditorNode.innerHTML = fck_text.innerHTML;
           return;
      }
  
 }

 function resetDokuWikiLockTimer(delete_checkbox) {

        var dom_checkbox = document.getElementById('fckg_timer');
        var dom_label = document.getElementById('fckg_timer_label');
        locktimer.clear();     
        if(ourLockTimerIsSet) {

             ourLockTimerIsSet = false;             
             locktimer.reset = locktimer.old_reset; 
             locktimer.refresh(); 
             dom_checkbox.style.display = 'inline';
             dom_label.style.display = 'inline';
             return;
        }
      
     if(delete_checkbox) {
       dom_checkbox.style.display = 'none';
       dom_label.style.display = 'none';
     }

       ourLockTimerIsSet = true;
       locktimer.reset = locktimer.ourLockTimerReset;     
       lockTimerRefresh();
          
 }

function renewLock() {
  if(ourLockTimerIsSet) {
         lockTimerRefresh();
   }
   else locktimer.refresh();
   locktimer.reset();
    
}

function disableDokuWikiLockTimer() {
  resetDokuWikiLockTimer(false);
  if(ourLockTimerIntervalID) {
     window.clearInterval(ourLockTimerIntervalID);
  }
  if(ourLockTimerIsSet) { 
    ourLockTimerIntervalID = window.setInterval(function () { locktimer.refresh(); }, 30000);   
  }
}

var oDokuWiki_FCKEditorInstance;
function FCKeditor_OnComplete( editorInstance )
{
  
  oDokuWiki_FCKEditorInstance = editorInstance;
  oDokuWiki_FCKEditorInstance.dwiki_user = "$user_type";
  document.getElementById('wiki__text___Frame').style.height = "450px";
  document.getElementById('size__ctl').innerHTML = document.getElementById('fck_size__ctl').innerHTML;

}


</script>
end_of_string;
  }
}
?>
